//////////////////////////////////////////////////////////////////////////////////////////////////
//					  Support_AutoEvents.cs					//
//Creator: Space Guy [ID 130]									//
//Allows you to set fields in brick datablocks for events to automatically be applied		//
//when the brick is planted.									//
//												//
//Set these fields in the brick datablock:							//
//autoApplyEvent_Input[0...n]		Input event name					//
//autoApplyEvent_Target[0...n]		Target Name (not Named Bricks)				//
//autoApplyEvent_Output[0...n]		Output event name					//
//autoApplyEvent_Param[0...n,0...4]:	Whatever the output parameter should be			//
//////////////////////////////////////////////////////////////////////////////////////////////////

if($SpaceMods::Server::AutoEventsVersion >= 1)
 return;

$SpaceMods::Server::AutoEventsVersion = 1;

package AutoApplyEvents
{
 function fxDTSBrick::onPlant(%this)
 {
  Parent::onPlant(%this);
  if(%this.dataBlock.autoApplyEvent_Input[0] !$= "" && %this != $LastLoadedBrick)
  {
   %this.schedule(25,applyDefaultEvents);
  }
 }
 function fxDTSBrick::applySpecialAttributes(%brick, %dupObj, %lineid, %client)
 {
  Parent::applySpecialAttributes(%brick, %dupObj, %lineid, %client);
  if(%brick.dataBlock.autoApplyEvent_Input[0] !$= "")
  {
   %brick.noDefaultEvents = 1;
  }
 }
 function fxDTSBrick::applyDefaultEvents(%this)
 {
  if(%this.noDefaultEvents)
   return;
  
  %owner = %this.getGroup().client;
  %oldWrenchBrick = %owner.wrenchBrick;
  %data = %this.dataBlock;
  
  %this.clearEvents();
  for(%i=0;%data.autoApplyEvent_Input[%i] !$= "";%i++)
  {
   %enabled = true;
   %delay = 0;
   %inputEventName = %data.autoApplyEvent_Input[%i];
   %targetName = %data.autoApplyEvent_Target[%i];
   %outputEventName = %data.autoApplyEvent_Output[%i];
   %inputEventIdx = inputEvent_GetInputEventIdx(%inputEventName);
   %targetIdx = inputEvent_GetTargetIndex("fxDTSBrick",%inputEventIdx,%targetName);
   %targetClass = inputEvent_GetTargetClass("fxDTSBrick",%inputEventIdx,%targetIdx);
   %outputEventIdx = outputEvent_GetOutputEventIdx(%targetClass,%outputEventName);
   %NamedTargetNameIdx = -1;
   
   for(%j=0;%j<5;%j++)
   {
    if(%data.autoApplyEvent_Param[%i,%j] !$= "")
     %p[%j] = %data.autoApplyEvent_Param[%i,%j];
   }
   
   %owner.wrenchBrick = %this;
   serverCmdAddEvent(%owner,%enabled,%inputEventIdx,%delay,%targetIdx,%NamedTargetNameIdx,%outputEventIdx,%p0,%p1,%p2,%p3,%p4);
   %owner.wrenchBrick = %oldWrenchBrick;
  }
 }

 function disconnect()
 {
  Parent::disconnect();
  $SpaceMods::Server::AutoEventsVersion = -1;
  schedule(10, 0, deActivatePackage, AutoApplyEvents); //we probably don't want to de-activate a package while we're in it, so schedule it 
 }
};

schedule(10,0,activatePackage,AutoApplyEvents);